==> core-0.0.25.tgz: package/src/components/Radio/props.ts <==
/**
 * File: /src/components/Radio/props.ts
 * Project: @native-theme-ui/core
 * File Created: 05-07-2022 06:24:30
 * Author: Clay Risser
 * -----
 * Last Modified: 30-08-2022 03:20:36
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Sx } from "dripsy";
import { StyledBoxProps } from "./index";
import { createUseSplitProps } from "../../util";

export type BasePropsBucket = StyledBoxProps;

export type RadioPropsBucket = {
  checked?: boolean;
  disabled?: boolean;
  name?: string;
};

export type CustomPropsBucket = {
  defaultChecked?: boolean;
};

export const useSplitProps = createUseSplitProps<
  RadioProps,
  {
    baseProps: BasePropsBucket;
    radioProps: RadioPropsBucket;
    customProps: CustomPropsBucket;
  },
  {
    baseSx: Sx;
    voidSx: Sx;
  },
  {
    baseStyle: Record<string, unknown>;
    voidStyle: Record<string, unknown>;
  }
>({
  radioProps: ["checked", "defaultChecked"],
});

export type RadioProps = Omit<
  BasePropsBucket & RadioPropsBucket & CustomPropsBucket,
  "showCursor"
>;

==> core-0.1.13.tgz: package/src/components/Radio/props.ts <==
/**
 * File: /src/components/Radio/props.ts
 * Project: @native-theme-ui/core
 * File Created: 05-07-2022 06:24:30
 * Author: Clay Risser
 * -----
 * Last Modified: 12-11-2022 15:38:57
 * Modified By: K S R P BHUSHAN
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Sx } from 'dripsy';
import { createUseSplitProps } from '../../util';
import { BoxProps } from '../Box';

export type BasePropsBucket = BoxProps;

export interface RadioPropsBucket {
  checked?: boolean;
  disabled?: boolean;
  name?: string;
  defaultChecked?: boolean;
}

export const useSplitProps = createUseSplitProps<
  RadioProps,
  {
    baseProps: BasePropsBucket;
    radioProps: RadioPropsBucket;
  },
  {
    baseSx: Sx;
    voidSx: Sx;
  },
  {
    baseStyle: Record<string, unknown>;
    voidStyle: Record<string, unknown>;
  }
>({
  radioProps: ['checked', 'defaultChecked'],
});

export type RadioProps = BasePropsBucket & RadioPropsBucket;
